/*
 *  LibRoadnav
 *  Address.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains the Address class, a class that contains a US address
///
//////////////////////////////////////////////////////////////////////////////

#ifndef ADDRESS_H
#define ADDRESS_H

#include "Point.h"
#include "MapControlDataEntry.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Describes a US address
///
//////////////////////////////////////////////////////////////////////////////
class Address
{
	public:
		Address();
	
		wxString FormatAddress(bool bShowCoordinates = true, bool bOneLine = false, bool bStreetOnly = false);

		wxString ToString();
		void FromString(wxString strValue);

		/// Street number of this address
		int m_iStreetNumber;
		
		/// Street name of this address
		wxString m_strStreetName;
		
		/// Type of street in abbreviation form (St, Ln, Rd, etc.)
		wxString m_strStreetType;
		
		/// City name
		wxString m_strCityName;
		
		/// State name (written out, New Hampshire, Vermont, etc.)
		wxString m_strStateName;
		
		/// Zip code
		int m_iZipCode;
		
		/// Long/lat coordinates of address
		Point m_ptCoordinates;

		/// 5 digit FIPS state + county code. Only set for RecordTypeCountyBoundary records.
		wxInt32 m_iCountyCode;

		/// Corresponding record ID
		tRecordID m_idRecord;
		
		/// Record type
		ERecordType m_eRecordType;

		/// Indicates if this object has been populated with information or not.
		bool m_bValid;
};

#endif
