/*
 *  LibRoadnav
 *  DownloadFiles.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Synchronous file download functions
///
//////////////////////////////////////////////////////////////////////////////

#ifndef DOWNLOAD_H
#define DOWNLOAD_H

#include <vector>

#include "ProgressDialog.h"

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Structure describing a file to download - URL, description,
/// output filename, etc.
///
//////////////////////////////////////////////////////////////////////////////
class SyncDownloadEntry
{
	public:
		SyncDownloadEntry();
		~SyncDownloadEntry();
		
		/// URL to download file from
		wxString m_strURL;
		
		/// Filename where URL should be downloaded
		wxString m_strOutputFilename;
		
		/// String to show in progress dialog while downloading file
		wxString m_strProgressBarName;
		
		/// Username to use for HTTP authentication (blank for no auth)
		wxString m_strUsername;
		
		/// Password to use for HTTP authentication (blank for no auth)
		wxString m_strPassword;

		/// Returns if the download completed successfully
		bool m_bDownloadedOkay;
		
		/// Socket timeout in seconds
		int m_iSocketTimeout;
		
		/// Attempts
		int m_iRetryAttempts;
};

int DownloadFiles(std::vector<SyncDownloadEntry> & vFiles, bool bProgressDialog = true, ProgressDialog * pdlgProgress = NULL, int iProgressStart = 0, int iProgressTicks = 1);
int DownloadFile(SyncDownloadEntry & sFile, bool bProgressDialog = true, ProgressDialog * pdlgProgress = NULL, int iProgressStart = 0, int iProgressTicks = 1);
void SetDownloadCacheDirectory(wxString strPath);
void SetProxyHost(wxString strProxyHost);
void SetProxyPort(int iProxyPort);
void SetProxyUsernamePassword(wxString strProxyUsername, wxString strProxyPassword);
wxString GetProxyHost();
int GetProxyPort();
void SetProxyFromURL(const wxString & strProxy);
void ClearDownloadCache();
bool IsValidURL(wxString strURL, wxString strUsername = wxT(""), wxString strPassword = wxT(""));

#endif
