/*
 *  LibRoadnav
 *  DownloadThread.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Contains a thread that performs downloads asynchronously
///
//////////////////////////////////////////////////////////////////////////////

#ifndef DOWNLOADTHREAD_H
#define DOWNLOADTHREAD_H

#include <wx/thread.h>

#include <list>

#define DL_ACTION_REFRESH		1

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Used by DownloadThread to store information about queued downloads
///
//////////////////////////////////////////////////////////////////////////////
struct SDownloadEntry
{
	/// Output filename for download
	wxString strFilename;

	/// URL to download from
	wxString strURL;

	/// Any DL_* actions to perform after the download is complete
	int iPostDownloadAction;
};

void QueueDownload(wxString strFilename, wxString strURL, int iPostDownloadAction);

//////////////////////////////////////////////////////////////////////////////
///
/// \brief wxThread responsible for performing background downloads
///
//////////////////////////////////////////////////////////////////////////////
class DownloadThread : public wxThread
{
	public:
		DownloadThread(wxWindow * pParent = NULL, int idRedrawNotification = -1);
		virtual void * Entry();

	private:
		/// Window that should receive completion notification
		wxWindow * m_pParent;
		
		/// Menu ID that should be triggered on DL_ACTION_REFRESH
		int m_idRedrawNotification;
};

#endif
