/*
 *  LibRoadnav
 *  MapSupport.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Support functions for the mapping code.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef MAPSUPPORT_H
#define MAPSUPPORT_H

#include <wx/wx.h>
#include <wx/config.h>

#include <vector>
#include <string>

#include "MapLookup.h"

#include "Point.h"
#include "Direction.h"

//////////////////////////////////////////////////////////////////////////////
/// Bitmap functions
//////////////////////////////////////////////////////////////////////////////
void CopyBitmap(wxBitmap & bmpSrc, wxBitmap & bmpDst);
wxBitmap ScaleDown(wxBitmap & bmpOriginal, int iAntiAliasingLevel);

//////////////////////////////////////////////////////////////////////////////
/// Coordinate relationships
//////////////////////////////////////////////////////////////////////////////
double Distance(Point a, Point b);
Direction Bearing(const wxPoint & a,const wxPoint & b);

//////////////////////////////////////////////////////////////////////////////
/// String handling
//////////////////////////////////////////////////////////////////////////////
char * ExtractField(char * pszText, int iStart, int iEnd);
void TrimWhitespace(char * p);
int wxtoi(const wxString & str);

//////////////////////////////////////////////////////////////////////////////
/// Misc
//////////////////////////////////////////////////////////////////////////////

double sin_deg(double x);
double cos_deg(double x);
double tan_deg(double x);

bool IsDataIntegrated(const wxString & strName);
void MarkDataIntegrated(const wxString & strName);
std::vector<std::string> GetIntegratedDataList();

void SaveWindowPosition(wxConfigBase * pConfig, wxWindow * pWnd, wxString strName);
void RestoreWindowPosition(wxConfigBase * pConfig, wxWindow * pWnd, wxString strName);

wxString GetDataPath(wxString strFilename = wxT(""), wxString strURL = wxT(""), bool bNonBlocking = false, bool bProgressDialog = true);
void SetCommonDataPath(wxString strCommonDataPath);
void SetLocalDataPath(wxString strLocalDataPath);

void RemoveDirectoryAndContents(wxString strName);

wxPoint RotatePoint(const wxPoint & ptTarget, const wxPoint & ptCenter, double fRotationAngle);
Point RotatePoint(const Point & ptTarget, const Point & ptCenter, double fRotationAngle);

wxString GetCommonDataPath();
wxString GetLocalDataPath();

bool SolveLinearEquationSet(double a1, double a2, double a3, double b1, double b2, double b3, double & x, double & y);

bool IsVowel(wxChar c);
double WordSimilarity(const wxString & strA, const wxString & strB);

const bool * AllVisibility();
const bool * OnlyRoadsVisibility();
bool VisibilityEqual(const bool * pb1, const bool * pb2);
void CopyVisibility(bool * pbDest, const bool * pbSrc);
bool LineIntersectsRect(const wxPoint & ptTopLeft, const wxPoint & ptBottomRight, const wxPoint & pt1, const wxPoint & pt2, bool bCheckTLBR = false);

wxUint32 EncodeCanadianZip(const wxString & strZip);
wxString DecodeCanadianZip(wxUint32 uiZip);

void SerializePointArray(FILE * hFile, bool bSave, Point * pcPoints, int nPoints, const Point & ptReference);

#endif
