/*
 *  LibRoadnav
 *  MapZip.h
 *
 *  Copyright (c) 2004 - 2007 Richard L. Lynch <rllynch@users.sourceforge.net>
 *
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

//////////////////////////////////////////////////////////////////////////////
/// \file
///
/// Maps zip codes to/from their cooresponding states and cities.
///
//////////////////////////////////////////////////////////////////////////////

#ifndef MAPZIP_H
#define MAPZIP_H

#include <wx/wx.h>

#include <vector>

#include "Point.h"
#include "AutoComplete.h"

bool LoadZipInformation(wxString strFilename);

std::vector<wxUint32> ZipCodesByCityState(wxString strCity, wxString strState);
const wxString & StateByZip(wxUint32 iZip);
const wxString & CityByZip(wxUint32 iZip);
wxInt32 CountyCodeByZip(wxUint32 iZip);
void MarkZipCodeCoordinates(int iZip, Point pt);
bool GetZipCodeCoordinates(int iZip, Point * pptTopLeft, Point * pptBottomRight);
wxString ClosestCityName(const wxString & strCity, const wxString & strState);
const wxString & StateAbbreviationByZip(wxUint32 iZip);

//////////////////////////////////////////////////////////////////////////////
///
/// \brief Autocompletes a city name
///
//////////////////////////////////////////////////////////////////////////////
class AutoComplete_City : public IAutoComplete
{
	public:
		AutoComplete_City();
		void SetState(const wxString & strState);		
		virtual wxString ClosestMatch(const wxString & strInput);
		virtual int GetUpdateDelay();
	
	private:
		wxString m_strState;
};

#endif
